@@ -42,62 +42,49 @@ class __TwigTemplate_55f91962626a7a309a423fa01c946f55 extends Template
         // line 1
         yield "<!DOCTYPE html>
 <html>
-";
-        // line 3
-        $context["brand"] = "Cause Buzz";
-        // line 4
-        yield "
-";
-        // line 5
-        yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Default/head.html.twig", ["headerTitle" => (((        $this->unwrap()->hasBlock("headerTitle", $context, $blocks) && !CoreExtension::inFilter(        $this->unwrap()->renderBlock("headerTitle", $context, $blocks), ["", "Mautic"]))) ? (((        $this->unwrap()->renderBlock("headerTitle", $context, $blocks) . " | ") .         // line 7
-(isset($context["brand"]) || array_key_exists("brand", $context) ? $context["brand"] : (function () { throw new RuntimeError('Variable "brand" does not exist.', 7, $this->source); })()))) : (        // line 8
-(isset($context["brand"]) || array_key_exists("brand", $context) ? $context["brand"] : (function () { throw new RuntimeError('Variable "brand" does not exist.', 8, $this->source); })()))), "pageTitle" => (((        $this->unwrap()->hasBlock("pageTitle", $context, $blocks) && !CoreExtension::inFilter(        $this->unwrap()->renderBlock("pageTitle", $context, $blocks), ["", "Mautic"]))) ? (((        $this->unwrap()->renderBlock("pageTitle", $context, $blocks) . " | ") .         // line 10
-(isset($context["brand"]) || array_key_exists("brand", $context) ? $context["brand"] : (function () { throw new RuntimeError('Variable "brand" does not exist.', 10, $this->source); })()))) : (        // line 11
-(isset($context["brand"]) || array_key_exists("brand", $context) ? $context["brand"] : (function () { throw new RuntimeError('Variable "brand" does not exist.', 11, $this->source); })())))]);
-        // line 12
-        yield "
+
     <body class=\"header-fixed\">
         <section id=\"app-wrapper\">
             ";
-        // line 15
+        // line 6
         yield $this->extensions['Mautic\CoreBundle\Twig\Extension\AssetExtension']->outputScripts("bodyOpen");
         yield "
 
             ";
-        // line 17
+        // line 8
         yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Notification/flashes.html.twig");
         yield "
             ";
-        // line 18
+        // line 9
         yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Menu/quick_help.html.twig");
         yield "
             ";
-        // line 19
+        // line 10
         yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Modal/tokens_help.html.twig");
         yield "
             ";
-        // line 20
+        // line 11
         yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Modal/keyboard_shortcuts.html.twig");
         yield "
             ";
-        // line 21
+        // line 12
         yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Modal/search_commands.html.twig");
         yield "
             ";
-        // line 22
+        // line 13
         yield $this->env->getRuntime('Symfony\Bridge\Twig\Extension\HttpKernelRuntime')->renderFragment(Symfony\Bridge\Twig\Extension\HttpKernelExtension::controller("Mautic\\CoreBundle\\Controller\\DefaultController::globalSearchAction"));
         yield "
 
             <aside class=\"app-sidebar sidebar-left\">
                 ";
-        // line 25
+        // line 16
         yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/LeftPanel/index.html.twig");
         yield "
             </aside>
 
             <header id=\"app-header\" class=\"navbar\">
                 ";
-        // line 29
+        // line 20
         yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Default/navbar.html.twig");
         yield "
             </header>
@@ -107,11 +94,11 @@ class __TwigTemplate_55f91962626a7a309a423fa01c946f55 extends Template
                 <div class=\"container-fluid\">
                     <div class=\"row\">
                         <div class=\"col-xs-6 text-muted\">© ";
-        // line 36
+        // line 27
         yield $this->env->getRuntime('Twig\Runtime\EscaperRuntime')->escape($this->extensions['Twig\Extension\CoreExtension']->formatDate("now", "Y"), "html", null, true);
         yield " Cause Buzz. Alle Rechte vorbehalten.</div>
                         <div class=\"col-xs-6 text-muted text-right small\">v";
-        // line 37
+        // line 28
         yield $this->env->getRuntime('Twig\Runtime\EscaperRuntime')->escape($this->extensions['Mautic\CoreBundle\Twig\Extension\VersionExtension']->getVersion(), "html", null, true);
         yield "</div>
                     </div>
@@ -121,17 +108,17 @@ class __TwigTemplate_55f91962626a7a309a423fa01c946f55 extends Template
 
             <section id=\"app-content\">
                 ";
-        // line 44
+        // line 35
         yield from $this->unwrap()->yieldBlock('_content', $context, $blocks);
-        // line 47
+        // line 38
         yield "            </section>
 
             <script>
                 Mautic.onPageLoad('body');
                 ";
-        // line 51
-        if ((CoreExtension::getAttribute($this->env, $this->source, (isset($context["app"]) || array_key_exists("app", $context) ? $context["app"] : (function () { throw new RuntimeError('Variable "app" does not exist.', 51, $this->source); })()), "environment", [], "any", false, false, false, 51) === "dev")) {
-            // line 52
+        // line 42
+        if ((CoreExtension::getAttribute($this->env, $this->source, (isset($context["app"]) || array_key_exists("app", $context) ? $context["app"] : (function () { throw new RuntimeError('Variable "app" does not exist.', 42, $this->source); })()), "environment", [], "any", false, false, false, 42) === "dev")) {
+            // line 43
             yield "                mQuery( document ).ajaxComplete(function(event, XMLHttpRequest, ajaxOption){
                     if(XMLHttpRequest.responseJSON && typeof XMLHttpRequest.responseJSON.ignore_wdt == 'undefined' && XMLHttpRequest.getResponseHeader('x-debug-token')) {
                         if (mQuery('[class*=\"sf-tool\"]').length) {
@@ -145,17 +132,49 @@ class __TwigTemplate_55f91962626a7a309a423fa01c946f55 extends Template
                 });
                 ";
         }
-        // line 64
+        // line 55
         yield "            </script>
+            <script>
+                (function() {
+
+                    const BRAND = 'Cause Buzz';
+
+                    function updateTitle() {
+
+                        let title = document.title || '';
+
+                        // Remove trailing \"| Mautic\"
+                        title = title.replace(/\\|\\s*Mautic\$/i, '').trim();
+
+                        // Remove duplicate brand
+                        title = title.replace(new RegExp('\\\\|\\\\s*' + BRAND + '\$', 'i'), '').trim();
+
+                        // If empty or just \"Mautic\"
+                        if (!title || title === 'Mautic') {
+                            document.title = BRAND;
+                            return;
+                        }
+
+                        document.title = title + ' | ' + BRAND;
+                    }
+
+                    // Initial load
+                    window.addEventListener('load', updateTitle);
+
+                    // Mautic SPA navigation event (official)
+                    document.addEventListener('mautic:page:load', updateTitle);
+
+                })();
+            </script>
 
             ";
-        // line 66
+        // line 89
         yield $this->extensions['Mautic\CoreBundle\Twig\Extension\AssetExtension']->outputScripts("bodyClose");
         yield "
             ";
-        // line 67
+        // line 90
         yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Helper/modal.html.twig", ["id" => "MauticSharedModal", "footerButtons" => true]);
-        // line 70
+        // line 93
         yield "
         </section>
     </body>
@@ -165,14 +184,14 @@ class __TwigTemplate_55f91962626a7a309a423fa01c946f55 extends Template
         yield from [];
     }
 
-    // line 44
+    // line 35
     /**
      * @return iterable<null|scalar|\Stringable>
      */
     public function block__content(array $context, array $blocks = []): iterable
     {
         $macros = $this->macros;
-        // line 45
+        // line 36
         yield "                    ";
         yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Default/output.html.twig");
         yield "
@@ -201,7 +220,7 @@ class __TwigTemplate_55f91962626a7a309a423fa01c946f55 extends Template
      */
     public function getDebugInfo(): array
     {
-        return array (  176 => 45,  169 => 44,  159 => 70,  157 => 67,  153 => 66,  149 => 64,  135 => 52,  133 => 51,  127 => 47,  125 => 44,  115 => 37,  111 => 36,  101 => 29,  94 => 25,  88 => 22,  84 => 21,  80 => 20,  76 => 19,  72 => 18,  68 => 17,  63 => 15,  58 => 12,  56 => 11,  55 => 10,  54 => 8,  53 => 7,  52 => 5,  49 => 4,  47 => 3,  43 => 1,);
+        return array (  195 => 36,  188 => 35,  178 => 93,  176 => 90,  172 => 89,  136 => 55,  122 => 43,  120 => 42,  114 => 38,  112 => 35,  102 => 28,  98 => 27,  88 => 20,  81 => 16,  75 => 13,  71 => 12,  67 => 11,  63 => 10,  59 => 9,  55 => 8,  50 => 6,  43 => 1,);
     }
 
     public function getSourceContext(): Source
