@@ -354,6 +354,6 @@ $context["item"], "templateButtons" => ["edit" => CoreExtension::getAttribute($t
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@MauticLead/Company/list.html.twig", "/var/www/html/mauticGIT-Test/app/bundles/LeadBundle/Resources/views/Company/list.html.twig");
+        return new Source("", "@MauticLead/Company/list.html.twig", "/var/www/html/staging-demo/app/bundles/LeadBundle/Resources/views/Company/list.html.twig");
     }
 }
